Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(497)

Unified Diff: chrome/browser/ui/views/exclusive_access_bubble_views.h

Issue 789403002: Rename fullscreen_exit_bubble_* to exclusive_access_bubble_* (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Updated based on CR comments Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/exclusive_access_bubble_views.h
diff --git a/chrome/browser/ui/views/fullscreen_exit_bubble_views.h b/chrome/browser/ui/views/exclusive_access_bubble_views.h
similarity index 67%
rename from chrome/browser/ui/views/fullscreen_exit_bubble_views.h
rename to chrome/browser/ui/views/exclusive_access_bubble_views.h
index 8af6d0e51e2375cc08adcde81c455b5e8866d505..f7e22e6758ce2c787556b25a74be171f53e2f0f6 100644
--- a/chrome/browser/ui/views/fullscreen_exit_bubble_views.h
+++ b/chrome/browser/ui/views/exclusive_access_bubble_views.h
@@ -2,12 +2,12 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_VIEWS_FULLSCREEN_EXIT_BUBBLE_VIEWS_H_
-#define CHROME_BROWSER_UI_VIEWS_FULLSCREEN_EXIT_BUBBLE_VIEWS_H_
+#ifndef CHROME_BROWSER_UI_VIEWS_EXCLUSIVE_ACCESS_BUBBLE_VIEWS_H_
+#define CHROME_BROWSER_UI_VIEWS_EXCLUSIVE_ACCESS_BUBBLE_VIEWS_H_
#include "base/compiler_specific.h"
#include "base/memory/scoped_ptr.h"
-#include "chrome/browser/ui/fullscreen/fullscreen_exit_bubble.h"
+#include "chrome/browser/ui/fullscreen/exclusive_access_bubble.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
#include "ui/views/widget/widget_observer.h"
@@ -22,26 +22,26 @@ class View;
class Widget;
}
-// FullscreenExitBubbleViews is responsible for showing a bubble atop the
-// screen in fullscreen mode, telling users how to exit and providing a click
-// target. The bubble auto-hides, and re-shows when the user moves to the
-// screen top.
-class FullscreenExitBubbleViews : public FullscreenExitBubble,
- public content::NotificationObserver,
- public views::WidgetObserver {
+// ExclusiveAccessBubbleViews is responsible for showing a bubble atop the
+// screen in fullscreen/mouse lock mode, telling users how to exit and providing
+// a click target. The bubble auto-hides, and re-shows when the user moves to
+// the screen top.
+class ExclusiveAccessBubbleViews : public ExclusiveAccessBubble,
+ public content::NotificationObserver,
+ public views::WidgetObserver {
public:
- FullscreenExitBubbleViews(BrowserView* browser,
- const GURL& url,
- FullscreenExitBubbleType bubble_type);
- ~FullscreenExitBubbleViews() override;
+ ExclusiveAccessBubbleViews(BrowserView* browser,
+ const GURL& url,
+ ExclusiveAccessBubbleType bubble_type);
+ ~ExclusiveAccessBubbleViews() override;
- void UpdateContent(const GURL& url, FullscreenExitBubbleType bubble_type);
+ void UpdateContent(const GURL& url, ExclusiveAccessBubbleType bubble_type);
// Repositions |popup_| if it is visible.
void RepositionIfVisible();
private:
- class FullscreenExitView;
+ class ExclusiveAccessView;
enum AnimatedAttribute {
ANIMATED_ATTRIBUTE_BOUNDS,
@@ -93,11 +93,11 @@ class FullscreenExitBubbleViews : public FullscreenExitBubble,
AnimatedAttribute animated_attribute_;
// The contents of the popup.
- FullscreenExitView* view_;
+ ExclusiveAccessView* view_;
content::NotificationRegistrar registrar_;
- DISALLOW_COPY_AND_ASSIGN(FullscreenExitBubbleViews);
+ DISALLOW_COPY_AND_ASSIGN(ExclusiveAccessBubbleViews);
};
-#endif // CHROME_BROWSER_UI_VIEWS_FULLSCREEN_EXIT_BUBBLE_VIEWS_H_
+#endif // CHROME_BROWSER_UI_VIEWS_EXCLUSIVE_ACCESS_BUBBLE_VIEWS_H_
« no previous file with comments | « chrome/browser/ui/fullscreen/fullscreen_exit_bubble_type.cc ('k') | chrome/browser/ui/views/exclusive_access_bubble_views.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698